@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 
 my %construct = (
@@ -76,7 +76,7 @@ Syntax::Construct - Identify which non-feature constructs are used in the code.
 
 =head1 VERSION
 
-Version 0.02
+Version 0.04
 
 =head1 SYNOPSIS
 
@@ -170,10 +170,16 @@ No constructs.
 
 =head3 computed-labels
 
+L<perl5180delta/Computed Labels>
+
 =head3 our-sub
 
+L<perl5180delta/Lexical Subroutines>
+
 =head3 state-sub
 
+L<perl5180delta/Lexical Subroutines>
+
 =head1 AUTHOR
 
 E. Choroba, C<< <choroba at cpan.org> >>
